@@ -3,7 +3,7 @@ package IO::Interactive;
 use strict;
 use warnings;
 
-$IO::Interactive::VERSION = '1.021_02';
+$IO::Interactive::VERSION = '1.021';
 
 sub is_interactive {
     my ($out_handle) = (@_, select);    # Default to default output handle
@@ -119,10 +119,9 @@ sub import {
     for my $request ( @_ ) {
         no strict 'refs';
         my $impl = *{$package.'::'.$request}{CODE};
-        if(!$impl || $request =~ m/\A _/xms) {
-            require Carp;
-            Carp::croak("Unknown subroutine ($request()) requested");
-        }
+        require Carp;
+        Carp::croak "Unknown subroutine ($request()) requested"
+            if !$impl || $request =~ m/\A _/xms;
         *{$caller.'::'.$request} = $impl;
     }
 }
@@ -245,8 +244,9 @@ None reported.
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to Github
-L<https://github.com/briandfoy/io-interactive/issues>.
+Please report any bugs or feature requests to
+C<bug-io-interactive@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org>.
 
 =head1 SOURCE AVAILABILITY
 
@@ -258,7 +258,7 @@ This code is in GitHub:
 
 Damian Conway  C<< <DCONWAY@cpan.org> >>
 
-Currently maintained by brian d foy C<< <bdfoy@cpan.org> >>.
+Currently maintained by brian d foy C<< <bdfoy@cpan.org> >>
 
 1.01 patch DMUEY C<< dmuey@cpan.org >>
 
